German Asphalt Pavement Distress Dataset (GAPs)
===============================================

The German Asphalt Pavement Distress (GAPs) dataset addresses the issue of
comparability in the pavement distress domain by providing a standardized
high-quality dataset of large size. This does not only enable researchers
to compare their work with other approaches, but also allows to analyze
algorithms on real world road surface evaluation data.

For details see the `GAPs dataset website
<http://www.tu-ilmenau.de/neurob/data-sets-code/gaps/>`.
